Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/vl53l0x_simpletest.py
    :caption: examples/vl53l0x_simpletest.py
    :linenos:

Multiple VL53L0X on Same I2C Bus
--------------------------------

Copy "../examples/vl53l0x_multiple_sensors.py" to your "CIRCUITPY" drive, then run the script with ``from vl53l0x_multiple_sensors import *``

.. literalinclude:: ../examples/vl53l0x_multiple_sensors.py
    :caption: examples/vl53l0x_multiple_sensors.py
    :linenos:
